/****************************************************************************************
|  Description: LED driver source file
|    File Name: led.c
|
|----------------------------------------------------------------------------------------
|                          C O P Y R I G H T
|----------------------------------------------------------------------------------------
|     Copyright (c) 2012 by Feaser     http://www.feaser.com     All rights reserved
|
|   This software is the property of Feaser. The source and compiled code may only be 
|        used on the Olimex EM32G880F128-STK board (http://www.olimex.com/dev).
| 
|      This copyright notice may not be removed from the source code nor changed.
|
|   This software has been carefully tested, but is not guaranteed for any particular
| purpose. The author does not offer any warranties and does not guarantee the accuracy,
|   adequacy, or completeness of the software and is not responsible for any errors or
|              omissions or the results obtained from use of the software.
|
****************************************************************************************/

/****************************************************************************************
* Include files
****************************************************************************************/
#include "header.h"                                   /* generic header file           */


/****************************************************************************************
* Macro definitions
****************************************************************************************/
#define LED_NUM          (4)                          /* total number of LEDs          */


/****************************************************************************************
* Local data declarations
****************************************************************************************/
static unsigned char ledStatus[LED_NUM];              /* keep track of on/off per LED  */


/****************************************************************************************
** NAME:           LedInit
** PARAMETER:      none
** RETURN VALUE:   none
** DESCRIPTION:    Initializes the LED driver.
**
****************************************************************************************/
void LedInit(void)
{
  /* 4 indicators on the LCD simulated the LEDs so no special initialization needs to
   * be done here. just make sure LcdInit() is called somewhere upon startup.
   */
} /*** end of LedInit ***/


/****************************************************************************************
** NAME:           LedSet
** PARAMETER:      id -> LED identifier. Can be LED_STATUS, LED_RED or LED_GREEN.
**                 on -> TRUE to turn the LED on, FALSE to turn it off.
** RETURN VALUE:   none
** DESCRIPTION:    Updates the status of the LED.
**
****************************************************************************************/
void LedSet(tLedId id, unsigned char on)
{
  lcdSymbol s;

  /* set the correct pin index */
  switch (id)
  {
    case LED_UP:
      s = LCD_SYMBOL_ARR_UP;
      break;
    case LED_DOWN:
      s = LCD_SYMBOL_ARR_DN;
      break;
    case LED_RIGHT:
      s = LCD_SYMBOL_ARR_R;
      break;
    case LED_LEFT:
      s = LCD_SYMBOL_ARR_L;
      break;
    default:
      s = LCD_SYMBOL_ARR_UP;
      break;
  }
  /* turn the LED on/off */
  LcdSymbol(s, on);
} /*** end of LedSet ***/


/****************************************************************************************
** NAME:           LedGet
** PARAMETER:      id -> LED identifier. Can be LED_STATUS, LED_RED or LED_GREEN.
** RETURN VALUE:   TRUE is the LED is currently on, FALSE otherwise.
** DESCRIPTION:    Obtains the status of the LED.
**
****************************************************************************************/
unsigned char LedGet(tLedId id)
{
  /* read and return the LED status */
  return ledStatus[id];
} /*** end of LedGet ***/


/************************************ end of led.c *************************************/


